@@ -20,7 +20,9 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = "0.0.3_02";
+our $VERSION = "0.0.3_03";
+my @supported_antiviruses = ("Armadito");
+my @supported_tasks = ("State","Enrolment","PullRequest");
 
 sub new {
     my ($class, %params) = @_;
@@ -49,6 +51,41 @@ sub init {
     );
 }
 
+sub isAVSupported {
+	my ($self, $antivirus) = @_;
+    foreach (@supported_antiviruses) {
+	  if( $antivirus eq $_ ) {
+		return 1;
+	  }
+	}
+	return 0;
+}
+
+sub isTaskSupported {
+	my ($self, $task) = @_;
+    foreach (@supported_tasks) {
+	  if( $task eq $_ ) {
+		return 1;
+	  }
+	}
+	return 0;
+}
+
+sub displaySupportedTasks {
+	my ($self) = @_;
+	print "List of supported tasks :\n";
+	foreach(@supported_tasks) {
+		print $_."\n";
+	}
+}
+
+sub displaySupportedAVs {
+	my ($self) = @_;
+	print "List of supported antiviruses :\n";
+	foreach(@supported_antiviruses) {
+		print $_."\n";
+	}
+}
 1;
 __END__
 =head1 NAME
@@ -57,7 +94,7 @@ Armadito::Agent - Armadito Agent
 
 =head1 VERSION
 
-0.0.3_02
+0.0.3_03
 
 =head1 DESCRIPTION
 
@@ -94,6 +131,22 @@ the options to use.
 
 Initialize the agent.
 
+=head2 isAVSupported($antivirus)
+
+Returns true if given antivirus is supported by the current version of the agent.
+
+=head2 isTaskSupported($task)
+
+Returns true if given task is supported by the current version of the agent.
+
+=head2 displaySupportedTasks()
+
+Display all currently supported tasks to stdout.
+
+=head2 displaySupportedAVs()
+
+Display all currently supported Antiviruses to stdout.
+
 =head1 SEE ALSO
 
 =over 4
